==> zio-aws-mediapackage_2.13-5.17.112.1-sources.jar: zio/aws/mediapackage/model/CmafPackageCreateOrUpdateParameters.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.{__string, __integer}
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CmafPackageCreateOrUpdateParameters(
    encryption: Option[zio.aws.mediapackage.model.CmafEncryption] = None,
    hlsManifests: Option[
      Iterable[zio.aws.mediapackage.model.HlsManifestCreateOrUpdateParameters]
    ] = None,
    segmentDurationSeconds: Option[__integer] = None,
    segmentPrefix: Option[__string] = None,
    streamSelection: Option[zio.aws.mediapackage.model.StreamSelection] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.CmafPackageCreateOrUpdateParameters = {
    import CmafPackageCreateOrUpdateParameters.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.CmafPackageCreateOrUpdateParameters
      .builder()
      .optionallyWith(encryption.map(value => value.buildAwsValue()))(
        _.encryption
      )
      .optionallyWith(
        hlsManifests.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.hlsManifests)
      .optionallyWith(
        segmentDurationSeconds.map(value => __integer.unwrap(value): Integer)
      )(_.segmentDurationSeconds)
      .optionallyWith(
        segmentPrefix.map(value => __string.unwrap(value): java.lang.String)
      )(_.segmentPrefix)
      .optionallyWith(streamSelection.map(value => value.buildAwsValue()))(
        _.streamSelection
      )
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackage.model.CmafPackageCreateOrUpdateParameters.ReadOnly =
    zio.aws.mediapackage.model.CmafPackageCreateOrUpdateParameters
      .wrap(buildAwsValue())
}
object CmafPackageCreateOrUpdateParameters {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.CmafPackageCreateOrUpdateParameters
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.mediapackage.model.CmafPackageCreateOrUpdateParameters =
      zio.aws.mediapackage.model.CmafPackageCreateOrUpdateParameters(
        encryption.map(value => value.asEditable),
        hlsManifests.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        segmentDurationSeconds.map(value => value),
        segmentPrefix.map(value => value),
        streamSelection.map(value => value.asEditable)
      )
    def encryption: Option[zio.aws.mediapackage.model.CmafEncryption.ReadOnly]
    def hlsManifests: Option[List[
      zio.aws.mediapackage.model.HlsManifestCreateOrUpdateParameters.ReadOnly
    ]]
    def segmentDurationSeconds: Option[__integer]
    def segmentPrefix: Option[__string]
    def streamSelection
        : Option[zio.aws.mediapackage.model.StreamSelection.ReadOnly]
    def getEncryption: ZIO[
      Any,
      AwsError,
      zio.aws.mediapackage.model.CmafEncryption.ReadOnly
    ] = AwsError.unwrapOptionField("encryption", encryption)
    def getHlsManifests: ZIO[Any, AwsError, List[
      zio.aws.mediapackage.model.HlsManifestCreateOrUpdateParameters.ReadOnly
    ]] = AwsError.unwrapOptionField("hlsManifests", hlsManifests)
    def getSegmentDurationSeconds: ZIO[Any, AwsError, __integer] = AwsError
      .unwrapOptionField("segmentDurationSeconds", segmentDurationSeconds)
    def getSegmentPrefix: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("segmentPrefix", segmentPrefix)
    def getStreamSelection: ZIO[
      Any,
      AwsError,
      zio.aws.mediapackage.model.StreamSelection.ReadOnly
    ] = AwsError.unwrapOptionField("streamSelection", streamSelection)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.CmafPackageCreateOrUpdateParameters
  ) extends zio.aws.mediapackage.model.CmafPackageCreateOrUpdateParameters.ReadOnly {
    override val encryption
        : Option[zio.aws.mediapackage.model.CmafEncryption.ReadOnly] = scala
      .Option(impl.encryption())
      .map(value => zio.aws.mediapackage.model.CmafEncryption.wrap(value))
    override val hlsManifests: Option[List[
      zio.aws.mediapackage.model.HlsManifestCreateOrUpdateParameters.ReadOnly
    ]] = scala
      .Option(impl.hlsManifests())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.mediapackage.model.HlsManifestCreateOrUpdateParameters
            .wrap(item)
        }.toList
      )
    override val segmentDurationSeconds: Option[__integer] = scala
      .Option(impl.segmentDurationSeconds())
      .map(value => zio.aws.mediapackage.model.primitives.__integer(value))
    override val segmentPrefix: Option[__string] = scala
      .Option(impl.segmentPrefix())
      .map(value => zio.aws.mediapackage.model.primitives.__string(value))
    override val streamSelection
        : Option[zio.aws.mediapackage.model.StreamSelection.ReadOnly] = scala
      .Option(impl.streamSelection())
      .map(value => zio.aws.mediapackage.model.StreamSelection.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.CmafPackageCreateOrUpdateParameters
  ): zio.aws.mediapackage.model.CmafPackageCreateOrUpdateParameters.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediapackage_2.13-5.17.145.1-sources.jar: zio/aws/mediapackage/model/CmafPackageCreateOrUpdateParameters.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.{__string, __integer}
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CmafPackageCreateOrUpdateParameters(
    encryption: Option[zio.aws.mediapackage.model.CmafEncryption] = None,
    hlsManifests: Option[
      Iterable[zio.aws.mediapackage.model.HlsManifestCreateOrUpdateParameters]
    ] = None,
    segmentDurationSeconds: Option[__integer] = None,
    segmentPrefix: Option[__string] = None,
    streamSelection: Option[zio.aws.mediapackage.model.StreamSelection] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.CmafPackageCreateOrUpdateParameters = {
    import CmafPackageCreateOrUpdateParameters.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.CmafPackageCreateOrUpdateParameters
      .builder()
      .optionallyWith(encryption.map(value => value.buildAwsValue()))(
        _.encryption
      )
      .optionallyWith(
        hlsManifests.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.hlsManifests)
      .optionallyWith(segmentDurationSeconds.map(value => value: Integer))(
        _.segmentDurationSeconds
      )
      .optionallyWith(segmentPrefix.map(value => value: java.lang.String))(
        _.segmentPrefix
      )
      .optionallyWith(streamSelection.map(value => value.buildAwsValue()))(
        _.streamSelection
      )
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackage.model.CmafPackageCreateOrUpdateParameters.ReadOnly =
    zio.aws.mediapackage.model.CmafPackageCreateOrUpdateParameters
      .wrap(buildAwsValue())
}
object CmafPackageCreateOrUpdateParameters {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.CmafPackageCreateOrUpdateParameters
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.mediapackage.model.CmafPackageCreateOrUpdateParameters =
      zio.aws.mediapackage.model.CmafPackageCreateOrUpdateParameters(
        encryption.map(value => value.asEditable),
        hlsManifests.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        segmentDurationSeconds.map(value => value),
        segmentPrefix.map(value => value),
        streamSelection.map(value => value.asEditable)
      )
    def encryption: Option[zio.aws.mediapackage.model.CmafEncryption.ReadOnly]
    def hlsManifests: Option[List[
      zio.aws.mediapackage.model.HlsManifestCreateOrUpdateParameters.ReadOnly
    ]]
    def segmentDurationSeconds: Option[__integer]
    def segmentPrefix: Option[__string]
    def streamSelection
        : Option[zio.aws.mediapackage.model.StreamSelection.ReadOnly]
    def getEncryption: ZIO[
      Any,
      AwsError,
      zio.aws.mediapackage.model.CmafEncryption.ReadOnly
    ] = AwsError.unwrapOptionField("encryption", encryption)
    def getHlsManifests: ZIO[Any, AwsError, List[
      zio.aws.mediapackage.model.HlsManifestCreateOrUpdateParameters.ReadOnly
    ]] = AwsError.unwrapOptionField("hlsManifests", hlsManifests)
    def getSegmentDurationSeconds: ZIO[Any, AwsError, __integer] = AwsError
      .unwrapOptionField("segmentDurationSeconds", segmentDurationSeconds)
    def getSegmentPrefix: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("segmentPrefix", segmentPrefix)
    def getStreamSelection: ZIO[
      Any,
      AwsError,
      zio.aws.mediapackage.model.StreamSelection.ReadOnly
    ] = AwsError.unwrapOptionField("streamSelection", streamSelection)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.CmafPackageCreateOrUpdateParameters
  ) extends zio.aws.mediapackage.model.CmafPackageCreateOrUpdateParameters.ReadOnly {
    override val encryption
        : Option[zio.aws.mediapackage.model.CmafEncryption.ReadOnly] = scala
      .Option(impl.encryption())
      .map(value => zio.aws.mediapackage.model.CmafEncryption.wrap(value))
    override val hlsManifests: Option[List[
      zio.aws.mediapackage.model.HlsManifestCreateOrUpdateParameters.ReadOnly
    ]] = scala
      .Option(impl.hlsManifests())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.mediapackage.model.HlsManifestCreateOrUpdateParameters
            .wrap(item)
        }.toList
      )
    override val segmentDurationSeconds: Option[__integer] =
      scala.Option(impl.segmentDurationSeconds()).map(value => value: __integer)
    override val segmentPrefix: Option[__string] =
      scala.Option(impl.segmentPrefix()).map(value => value: __string)
    override val streamSelection
        : Option[zio.aws.mediapackage.model.StreamSelection.ReadOnly] = scala
      .Option(impl.streamSelection())
      .map(value => zio.aws.mediapackage.model.StreamSelection.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.CmafPackageCreateOrUpdateParameters
  ): zio.aws.mediapackage.model.CmafPackageCreateOrUpdateParameters.ReadOnly =
    new Wrapper(impl)
}
